;;; Default Prelude for LispPad
;;;
;;; Author: Matthias Zenger
;;; Copyright © 2018 Matthias Zenger. All rights reserved.
;;;
;;; Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file
;;; except in compliance with the License. You may obtain a copy of the License at
;;;
;;;   http://www.apache.org/licenses/LICENSE-2.0
;;;
;;; Unless required by applicable law or agreed to in writing, software distributed under the
;;; License is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
;;; either express or implied. See the License for the specific language governing permissions
;;; and limitations under the License.

;; Import (lispkit base) and (lispkit draw) from the LispKit release
(import (lispkit base))
(import (lispkit draw))

;; Import (lisppad system) from the LispPad application
(import (lisppad system))

(define random
  (let ((a 69069)
        (c 1)
        (m (expt 2 32))
        (seed 19380110))
    (lambda new-seed
      (if (pair? new-seed)
          (set! seed (car new-seed))
          (set! seed (modulo (+ (* seed a) c) m)))
      (inexact (/ seed m)))))

(define random-integer
  (case-lambda
    ((hi)
      (exact (floor (* (random) hi))))
    ((lo hi)
      (+ lo (exact (floor (* (random) (- hi lo))))))))

(define d (make-drawing))
(set-fill-color black d)
(fill (circle '(50.0 . 50.0) 40.0) d)
(set-fill-color red d)
(fill (circle '(150.0 . 50.0) 40.0) d)
(set-fill-color gray d)
(fill (circle '(250.0 . 50.0) 40.0) d)
(set-fill-color green d)
(fill (circle '(100.0 . 150.0) 40.0) d)
(set-fill-color blue d)
(fill (circle '(200.0 . 150.0) 40.0) d)
(set-fill-color yellow d)
(fill (circle '(300.0 . 150.0) 40.0) d)
(set-fill-color yellow d)
(fill (circle '(150.0 . 250.0) 40.0) d)
(set-color black d)
(draw (circle '(250.0 . 250.0) 40.0) 1.0 d)
(set-fill-color red d)
(fill (circle '(350.0 . 250.0) 40.0) d)
(draw (circle '(350.0 . 250.0) 40.0) 1.0 d)
(set-fill-color red d)
(fill (circle '(200.0 . 350.0) 40.0) d)
(set-color black d)
(draw (circle '(300.0 . 350.0) 40.0) 1.0 d)
(set-fill-color green d)
(fill (circle '(400.0 . 350.0) 40.0) d)
(draw (circle '(400.0 . 350.0) 40.0) 1.0 d)

(define (win) (make-graphics-window d '(300.0 . 300.0) "my window" '(50.0 . 50.0) '(800.0 . 600.0)))
